# Deprecation Notice

[avro-python3](https://pypi.org/project/avro-python3/) is no longer maintained and is deprecated in favor of [avro](https://pypi.org/project/avro/). Avro is maintained and has full support for recent versions of Python.

## Apache Avro™

Apache Avro™ is a data serialization system. To learn more, please visit our [website](https://avro.apache.org/).


### Documentation

Apache Avro documentation is maintained on our [wiki](https://cwiki.apache.org/confluence/display/AVRO/Index).


### Contributing

To contribute to Avro, please read [How to Contribute](https://cwiki.apache.org/confluence/display/AVRO/How+To+Contribute) on the wiki.


### License, Credits and Acknowledgements

License, credits and acknowledgements are maintained in the [LICENSE.txt](https://github.com/apache/avro/blob/master/LICENSE.txt) and [NOTICE.txt](https://github.com/apache/avro/blob/master/NOTICE.txt) in the source code repository. Those files are also included with the installed package.
